@@ -33,6 +33,14 @@
 # include <linux/wanpipe_cfg_atm.h>
 # include <linux/wanpipe_cfg_lip.h>
 # include <linux/wanpipe_cfg_adsl.h>
+
+#ifndef wan_time_t 
+#define wan_time_t unsigned long
+#endif
+#ifndef wan_suseconds_t
+#define wan_suseconds_t unsigned long
+#endif
+
 #elif defined(__WINDOWS__)
 # include <sdla_56k.h>
 # include <sdla_te1.h>
