@@ -234,9 +234,9 @@ static int sdla_te3_set_status(sdla_fe_t *fe)
 
 				if (fe->fe_param.te3.e3_lb_ctrl==2) {
 					fe->fe_param.te3.e3_connect_delay++;
-					DEBUG_EVENT("%s: Waiting for link up %i/10...!\n", 
+					DEBUG_EVENT("%s: Waiting for link up %i/8...!\n", 
 								fe->name,fe->fe_param.te3.e3_connect_delay);
-					if (fe->fe_param.te3.e3_connect_delay >= 10) {
+					if (fe->fe_param.te3.e3_connect_delay >= 8) {
 						DEBUG_EVENT("%s: Link Up Timeout - Link in loopback!\n", fe->name);
 						sdla_te3_set_lb_modes_all(fe,WAN_TE3_LIU_LB_REMOTE,WAN_TE3_LB_DISABLE);
 						fe->fe_param.te3.e3_lb_ctrl=4;
@@ -248,9 +248,8 @@ static int sdla_te3_set_status(sdla_fe_t *fe)
 		}else{
 
 			if (fe->fe_status != FE_CONNECTED){
-
 				fe->fe_param.te3.e3_connect_delay++;
-				if (fe->fe_param.te3.e3_connect_delay >= 5) {
+			  	if (fe->fe_param.te3.e3_connect_delay >= 5) {
 					fe->fe_param.te3.e3_connect_delay=0;
 
 					if (fe->fe_param.te3.e3_lb_ctrl == 0) {
@@ -266,8 +265,19 @@ static int sdla_te3_set_status(sdla_fe_t *fe)
 					DEBUG_EVENT("%s: E3 connected! State=%i\n",
 							fe->name,fe->fe_param.te3.e3_lb_ctrl);
 					fe->fe_status = FE_CONNECTED;
+			   	} 
+			} else { 
+				if (fe->fe_param.te3.e3_lb_ctrl==1) {
+					fe->fe_param.te3.e3_connect_delay++;
+					DEBUG_EVENT("%s: Waiting for link down %i/10...!\n", 
+						fe->name,fe->fe_param.te3.e3_connect_delay);
+					if (fe->fe_param.te3.e3_connect_delay > 10) {
+						sdla_te3_set_lb_modes_all(fe,WAN_TE3_LIU_LB_REMOTE,WAN_TE3_LB_DISABLE);
+						fe->fe_param.te3.e3_lb_ctrl = 3;
+						fe->fe_param.te3.e3_connect_delay=0;
+					}
 				}
-			}
+		  	}
 			
 		}
 	}else{
