@@ -837,7 +837,7 @@ static int probe_get_info(char* buf, char** start, off_t offs, int len, int dumm
 		PROC_ADD_LINE(m, "A300=%d ", hw_cnt->aft300_adapters);
 	}
 	if (hw_cnt->aft_a600_adapters){
-		PROC_ADD_LINE(m, "A600=%d ", hw_cnt->aft_a600_adapters);
+		PROC_ADD_LINE(m, "B600=%d ", hw_cnt->aft_a600_adapters);
 	}
 	PROC_ADD_LINE(m, "\n");
 
@@ -880,7 +880,7 @@ static int probe_get_info_legacy(char* buf, char** start, off_t offs, int len, i
 	hw_cnt=(sdla_hw_type_cnt_t*)sdla_get_hw_adptr_cnt();	
 	
 	PROC_ADD_LINE(m,
-		"\nCard Cnt: S508=%d S514X=%d S518=%d A101-2=%d A104=%d A300=%d A200=%d A108=%d A056=%d\n          A500=%d A14x=%d A600=%d\n",
+		"\nCard Cnt: S508=%d S514X=%d S518=%d A101-2=%d A104=%d A300=%d A200=%d A108=%d A056=%d\n          A500=%d A14x=%d B600=%d\n",
 		hw_cnt->s508_adapters,
 		hw_cnt->s514x_adapters,
 		hw_cnt->s518_adapters,
@@ -970,7 +970,7 @@ static int probe_get_info_verbose(char* buf, char** start, off_t offs, int len,
 		PROC_ADD_LINE(m, "A300=%d ", hw_cnt->aft300_adapters);
 	}
 	if (hw_cnt->aft_a600_adapters){
-		PROC_ADD_LINE(m, "A600=%d ", hw_cnt->aft_a600_adapters);
+		PROC_ADD_LINE(m, "B600=%d ", hw_cnt->aft_a600_adapters);
 	}
 	PROC_ADD_LINE(m, "\n");
 
@@ -1011,7 +1011,7 @@ static int probe_get_info_dump(char* buf, char** start, off_t offs, int len, int
 	
 
 	PROC_ADD_LINE(m,
-		"|Card Cnt|S508=%d|S514X=%d|S518=%d|A101-2=%d|A104=%d|A300=%d|A200=%d|A108=%d|A056=%d|A500=%d|A14x=%d\n",
+		"|Card Cnt|S508=%d|S514X=%d|S518=%d|A101-2=%d|A104=%d|A300=%d|A200=%d|A108=%d|A056=%d|A500=%d|A14x=%d|B600=%d\n",
 		hw_cnt->s508_adapters,
 		hw_cnt->s514x_adapters,
 		hw_cnt->s518_adapters,
@@ -1022,7 +1022,8 @@ static int probe_get_info_dump(char* buf, char** start, off_t offs, int len, int
 		hw_cnt->aft108_adapters,
 		hw_cnt->aft_56k_adapters,
 		hw_cnt->aft_isdn_adapters,
-		hw_cnt->aft_serial_adapters
+		hw_cnt->aft_serial_adapters,
+                hw_cnt->aft_a600_adapters
 		);
 
 	PROC_ADD_RET(m);
