@@ -62,14 +62,6 @@ enum	e_sigboost_call_setup_ack_nack_cause_values
 	//SIGBOOST_CALL_SETUP_NACK_AUTO_CALL_GAP	= 0x17,
 };
 
-enum	e_sigboost_huntgroup_values
-{
-	SIGBOOST_HUNTGRP_SEQ_ASC	= 0x00, /* sequential with lowest available first */
-	SIGBOOST_HUNTGRP_SEQ_DESC	= 0x01, /* sequential with highest available first */
-	SIGBOOST_HUNTGRP_RR_ASC		= 0x02, /* round-robin with lowest available first */
-	SIGBOOST_HUNTGRP_RR_DESC	= 0x03, /* round-robin with highest available first */
-};
-
 #define MAX_DIALED_DIGITS	31
 #define MAX_CALLING_NAME	31
 
@@ -95,7 +87,6 @@ typedef struct
 #endif
 	uint16_t	call_setup_id;
 	uint32_t	trunk_group;
-	uint32_t	hunt_group;
 	uint32_t	span;
 	uint32_t	chan;
 	uint8_t		called_number_digits_count;
@@ -114,7 +105,6 @@ typedef struct
 	/* redir string format: 
 	 * http://www.ss7box.com/wiki/tiki-index.php?page=Call+Redirection
 	 * */
-
 } t_sigboost;
 #pragma pack()
 
